<?php

require __DIR__ . '/config.php';
require __DIR__ . '/functions.php';
require '/usr/local/cpanel/php/cpanel.php';  // Instantiate the CPANEL object.

$cpanel = new CPANEL();  // Connect to cPanel - only do this once.

$resultA = $cpanel->uapi('Locale', 'get_attributes');  // Get the user's current locale setting.

if ($resultA['cpanelresult']['result']['status'] && !empty($resultA['cpanelresult']['result']['data']['locale'])) {
    $locale = $resultA['cpanelresult']['result']['data']['locale'];
    
    if (file_exists(__DIR__ . '/langs/lang-' . $locale . '.php'))
        include __DIR__ . '/langs/lang-' . $locale . '.php';
    else
        include __DIR__ . '/langs/lang-en.php';
} else
    include __DIR__ . '/langs/lang-en.php';

echo $cpanel->header('', 'modSecurity-control');  // Add the header.
?>
<link rel="stylesheet" type="text/css" href="css/domain-log.css">
<script src="/unprotected/libraries/jquery/current/jquery.min.js"></script>
<?php
$user = $cpanel->cpanelprint('$user');
$domain = $_GET['domain'];

if (!empty($domain)) {
    // Get the config of the domain.
    $params = ['config' => STD_PATH.'/'.$user.'/'.$domain.'/modsec.conf'];
    $result = callWhmApi('modsec_get_config_text', $params);
    $uriList = [];  // List of URIs which remove the specified rule ID.
    
    // Get the list of URIs which remove this rule ID.
    if ($result['metadata']['result'] && !empty($result['data']['text']) &&
        preg_match_all('/<LocationMatch "(.+)">\s*SecRuleRemoveById (\d+)\s*<\/LocationMatch>/sU', $result['data']['text'], $uriMatches) > 0) {  // URIs
            foreach ($uriMatches[2] as $key => $ruleId) {
                $uriList[] = ['uri' => $uriMatches[1][$key], 'ruleId' => $ruleId];
            }
    }
?>
<div>
    <div class="form-group">
        <a href="index.live.php" class="btn btn-primary"><?php echo $LANG['Return']; ?></a>
    </div>
    <div id="alert-container" class="alert-container">
        <div id="alert-danger" class="alert alert-danger">
            <button class="close">×</button>
            <span class="glyphicon glyphicon-remove-sign"></span>
            <div class="alert-message">
                <strong class="alert-title"><?php echo $LANG['Error:']; ?></strong>
                <span class="alert-body"></span>
            </div>
        </div>
        <div id="alert-success" class="alert alert-success">
            <button class="close">×</button>
            <span class="glyphicon glyphicon-ok-sign"></span>
            <div class="alert-message">
                <strong class="alert-title"><?php echo $LANG['Success:']; ?></strong>
                <span class="alert-body"></span>
            </div>
        </div>
    </div>
    <table class="table table-bordered table-striped section">
        <thead>
            <tr>
                <th colspan="4"><?php echo $LANG['ModSecurity Log Entries'].' ['.$LANG['Domain: '].$domain.']'; ?>
                    <button class="btn btn-primary glyphicon glyphicon-resize-vertical pull-right" id="all-submenu-btn"></button>
                </th>
            </tr>
        </thead>
        <tbody>
<?php
    $matchedData = false;
    
    $params = [
        'api.filter.enable' => 1,
        'api.filter.a.field' => 'host',
        'api.filter.a.arg0' => $domain,
        'api.filter.a.type' => 'contains',
        'api.sort.enable' => 1,
        'api.sort.a.field' => 'timestamp',
        'api.sort.a.reverse' => 1,
        'api.chunk.enable' => 1,
        'api.chunk.size' => 300,
    ];
    
    $log = callWhmApi('modsec_get_log', $params);
    
        $index = 0;
        
        foreach ($log['data']['data'] as $data) {
            if ($data['host'] == $domain || $data['host'] == 'www.' . $domain) {
                $matchedData = true;
                $targetPath = preg_replace('/\?.*/', '', $data['path']);
                $domainRuleIdStatus = true;
                
                foreach ($uriList as $ul) {
                    if ($ul['uri'] == $targetPath && $ul['ruleId'] == $data['meta_id']) {
                        $domainRuleIdStatus = false;
                        break;
                    }
                }
?>
            <tr>
                <td class="col-xs-1">Rule ID</td>
                <td class="col-xs-4">Path</td>
                <td class="col-xs-4">Target Path</td>
                <td class="col-xs-3">Date Time</td>
            </tr>
            <tr>
                <td><strong><?php echo $data['meta_id']; ?></strong></td>
                <td class="word-break-all"><?php echo $data['path']; ?></td>
                <td class="word-break-all">
                    <span class="td-line-height"><?php echo $targetPath; ?></span>
                    <div class="btn-group btn-group-nowrap path-rule-id-btn pull-right">
                        <a href="javascript:void(0)" class="disable-path-rule-id btn<?php if ($domainRuleIdStatus) { ?> btn-primary<?php } else { ?> btn-default btn-none disabled<?php } ?>"
                        data-rule-id="<?php echo $data['meta_id']; ?>" data-path="<?php echo htmlspecialchars($targetPath); ?>"><?php echo $LANG['Add to the whitelist']; ?></a>
                    </div>
                    <img src="images/loading.gif" class="loading pull-right">
                </td>
                <td>
                    <span class="td-line-height"><?php echo date('Y/m/d H:i:s', strtotime($data['timestamp'])); ?></span>
                    <button class="btn btn-primary glyphicon glyphicon-resize-vertical pull-right submenu-btn" data-index="<?php echo ++$index; ?>"></button>
                </td>
            </tr>
            <tr>
                <td colspan="4">
                    <div><?php echo $data['justification']; ?></div>
                    <div class="submenu" id="submenu-<?php echo $index; ?>">
                        <div><strong>Log Data:</strong> <?php echo htmlspecialchars($data['meta_logdata']); ?></div>
                        <div><strong>HTTP Status:</strong> <?php echo $data['http_status']; ?></div>
                        <div><strong>Message:</strong> <?php echo $data['meta_msg']; ?></div>
                        <div><strong>HTTP Method:</strong> <?php echo $data['http_method']; ?></div>
                        <div><strong>Severity:</strong> <?php echo $data['meta_severity']; ?></div>
                        <div><strong>Action Description:</strong> <?php echo $data['action_desc']; ?></div>
                        <div><strong>HTTP Version:</strong> <?php echo $data['http_version']; ?></div>
                    </div>
                </td>
            </tr>
<?php
            }
        }
    
    if (!$matchedData) {
?>
            <tr>
                <td colspan="4"><?php echo $LANG['No data']; ?></td>
            </tr>
<?php } ?>
        </tbody>
    </table>
</div>
<script type="text/javascript">
$(function () {
    $('#all-submenu-btn').click(function () {
        $('.submenu').toggle();
    });
    
    $('.submenu-btn').click(function () {
        var index = $(this).attr('data-index');
        $('#submenu-' + index).toggle();
    });
    
    $('.disable-path-rule-id').click(function () {
        var dom = $(this);
        
        if (dom.hasClass('disabled'))
            return false;
        
        var ruleId = dom.attr('data-rule-id');
        var path = dom.attr('data-path');
        
        if (ruleId != '' && path != '') {
            $.ajax({
                url: 'disable-path-rule-id.live.php',
                type: 'POST',
                data: {user: '<?php echo $user; ?>',
                       ruleId: ruleId,
                       domain: '<?php echo $domain; ?>',
                       path: path},
                success: function (msg) {
                    if (msg.trim().substring(0, 7) == 'success') {
                        dom.removeClass('btn-primary').addClass('btn-default btn-none disabled');
                        $('#alert-success .alert-body').text('Rule ID ' + ruleId + ' <?php echo $LANG['Path: ']; ?>' + path + ' <?php echo $LANG['has been added to the whitelist.']; ?>');
                        $('#alert-success').show();
                    } else if (msg.trim().substring(0, 17) == 'SecRuleEngine Off') {
                        $('#alert-danger .alert-body').text('<?php echo $LANG['All the vendors of the domain "'].$domain.$LANG['" are disabled.']; ?>');
                        $('#alert-danger').show();
                        $('html, body').animate({scrollTop: 0});
                    } else if (msg.trim().substring(0, 7) == 'existed') {
                        $('#alert-danger .alert-body').text('Rule ID ' + ruleId + ' <?php echo $LANG['Path: ']; ?>' + path + ' <?php echo $LANG['has been existed.']; ?>');
                        $('#alert-danger').show();
                        $('html, body').animate({scrollTop: 0});
                    } else {
                        console.log(msg);
                        $('#alert-danger .alert-body').text('<?php echo $LANG['Unable to add']; ?> Rule ID ' + ruleId + ' <?php echo $LANG['Path: ']; ?>' + path + ' <?php echo $LANG['to the whitelist.']; ?>');
                        $('#alert-danger').show();
                        $('html, body').animate({scrollTop: 0});
                    }
                    
                    $('#alert-container').fadeIn();
                },
                beforeSend: function () {
                    $('.disable-path-rule-id').addClass('disabled');
                    dom.parents('td').find('.loading').show();
                    $('#alert-container').hide();
                    $('#alert-container .alert').hide();
                },
                complete: function () {
                    $('.disable-path-rule-id').removeClass('disabled');
                    dom.parents('td').find('.loading').hide();
                }
            });
        }
    });
});
</script>
<?php } else { ?>
<div>
    <div class="alert alert-danger">
        <span class="glyphicon glyphicon-remove-sign"></span>
        <div class="alert-message">
            <strong class="alert-title"><?php echo $LANG['Error:']; ?></strong>
            <span class="alert-body"><?php echo $LANG['No domain name']; ?></span>
        </div>
    </div>
</div>
<?php } ?>
<script type="text/javascript">
$(function () {
    $('title').append('<?php echo $LANG['ModSecurity Control']; ?>');
    $('#pageHeading').text('<?php echo $LANG['ModSecurity Control']; ?>');
});
</script>
<?php
echo $cpanel->footer();  // Add the footer.

$cpanel->end();  // Disconnect from cPanel - only do this once.
?>
